Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(72)

Unified Diff: components/payments/content/payment_request_web_contents_manager.h

Issue 2866623003: PaymentRequest.canMakePayment() query quota on desktop. (Closed)
Patch Set: frame Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/payments/content/payment_request_web_contents_manager.h
diff --git a/components/payments/content/payment_request_web_contents_manager.h b/components/payments/content/payment_request_web_contents_manager.h
index 1c000ec33ed3be157d6b0a498eb3cf24856a95b8..1d4a538ecb05efec852af6fff3ae48f4b426f3b0 100644
--- a/components/payments/content/payment_request_web_contents_manager.h
+++ b/components/payments/content/payment_request_web_contents_manager.h
@@ -15,6 +15,7 @@
#include "mojo/public/cpp/bindings/binding.h"
namespace content {
+class RenderFrameHost;
class WebContents;
}
@@ -40,8 +41,10 @@ class PaymentRequestWebContentsManager
static PaymentRequestWebContentsManager* GetOrCreateForWebContents(
content::WebContents* web_contents);
// Creates the PaymentRequest that will interact with this |web_contents|.
void CreatePaymentRequest(
+ content::RenderFrameHost* render_frame_host,
content::WebContents* web_contents,
std::unique_ptr<PaymentRequestDelegate> delegate,
mojo::InterfaceRequest<payments::mojom::PaymentRequest> request,
@@ -40,8 +41,10 @@ class PaymentRequestWebContentsManager
static PaymentRequestWebContentsManager* GetOrCreateForWebContents(
content::WebContents* web_contents);
- // Creates the PaymentRequest that will interact with this |web_contents|.
+ // Creates the PaymentRequest that will interact with this |render_frame_host|
+ // and the associated |web_contents|.
void CreatePaymentRequest(

Powered by Google App Engine
This is Rietveld 408576698